Name:           xmlrpc
Version:        3.1.3
Release:        %mkrel 79
Group:          Development/Java
Epoch:          1
Summary:        Java XML-RPC implementation
License:        ASL 2.0
URL:            https://ws.apache.org/xmlrpc/
BuildArch:      noarch

Source0:        https://archive.apache.org/dist/ws/xmlrpc/sources/apache-xmlrpc-%{version}-src.tar.bz2

# Fix build against modern servlet API by implementing missing interfaces
Patch0: 0001-Javax-Servlet-API.patch
# Add OSGi metadata so that xmlrpc can be used in OSGi runtimes
Patch1: 0002-Add-OSGi-metadata.patch
# CVE-2016-5003 - Disallow deserialization of <ex:serializable> tags by default
Patch2: 0003-disallow-deserialization-of-ex-serializable-tags.patch
# CVE-2016-5002 - isallow loading of external DTD
Patch3: 0004-disallow-loading-external-dtd.patch
# Jakarta Commons HttpClient is obsolete and should not be used, one of the other
# provider implementations should by used instead by clients of xmlrpc
Patch4: 0005-Remove-dep-on-ancient-commons-httpclient.patch
# CVE-2019-17570 - Deserialization of server-side exception from faultCause in XMLRPC error response
Patch5: 0006-Fix-for-CVE-2019-17570.patch

BuildRequires:  maven-local
BuildRequires:  mvn(commons-logging:commons-logging)
BuildRequires:  mvn(javax.servlet:javax.servlet-api)
BuildRequires:  mvn(javax.xml.bind:jaxb-api)
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(org.apache:apache:pom:)
BuildRequires:  mvn(org.apache.ws.commons.util:ws-commons-util)

%description
Apache XML-RPC is a Java implementation of XML-RPC, a popular protocol
that uses XML over HTTP to implement remote procedure calls.

%package javadoc
Summary: Javadoc for %{name}

%description javadoc
Javadoc for %{name}.

%package common
Summary: Common classes for XML-RPC client and server implementations

%description common
%{summary}.

%package client
Summary: XML-RPC client implementation

%description client
%{summary}.

%package server
Summary: XML-RPC server implementation

%description server
%{summary}.

%prep
%setup -q -n apache-%{name}-%{version}-src

%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1

sed -i 's/\r//' LICENSE.txt

%pom_disable_module dist
%pom_remove_dep jaxme:jaxmeapi common
%pom_add_dep junit:junit:3.8.1:test

%pom_remove_plugin :maven-javadoc-plugin

# Add missing dep when building against Java 11
%pom_add_dep javax.xml.bind:jaxb-api:2.2.12

# don't hard code source and target levels
sed -i -e '/<source>/d' \
       -e '/<target>/d' pom.xml

%mvn_file :{*} @1
%mvn_package :*-common %{name}

%build
# ignore test failure because server part needs network
%mvn_build -s -- -Dmaven.test.failure.ignore=true \
  -Dmaven.compiler.source=1.8 -Dmaven.compiler.target=1.8

%install
%mvn_install

%files common -f .mfiles-%{name}
%license LICENSE.txt NOTICE.txt

%files client -f .mfiles-%{name}-client

%files server -f .mfiles-%{name}-server

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt NOTICE.txt




%changelog
* Sat Mar 26 2022 umeabot <umeabot> 1:3.1.3-79.mga9
+ Revision: 1827665
- Mageia 9 Mass Rebuild

* Mon Jan 04 2021 neoclust <neoclust> 1:3.1.3-78.mga8
+ Revision: 1668715
- Do not use old commons httpclient

* Mon Dec 21 2020 neoclust <neoclust> 1:3.1.3-77.mga8
+ Revision: 1662676
- Disable tests
+ luigiwalser <luigiwalser>
- allow building on Java 11

* Thu Feb 20 2020 umeabot <umeabot> 1:3.1.3-75.mga8
+ Revision: 1545968
- Mageia 8 Mass Rebuild

* Fri Jan 31 2020 daviddavid <daviddavid> 1:3.1.3-74.mga8
+ Revision: 1485690
- add patch to fix CVE-2019-17570 (mga#26090)

* Tue Jan 01 2019 luigiwalser <luigiwalser> 1:3.1.3-73.mga7
+ Revision: 1347897
- add patches from fedora to fix CVE-2016-500[23]

* Wed Sep 19 2018 umeabot <umeabot> 1:3.1.3-72.mga7
+ Revision: 1277257
- Mageia 7 Mass Rebuild
+ neoclust <neoclust>
- Second rebuild of the java stack

* Thu Feb 18 2016 umeabot <umeabot> 1:3.1.3-70.mga6
+ Revision: 965244
- Mageia 6 Mass Rebuild

* Fri Dec 26 2014 dmorgan <dmorgan> 1:3.1.3-69.mga5
+ Revision: 806149
- Sync with fc21

* Wed Oct 15 2014 umeabot <umeabot> 1:3.1.3-7.mga5
+ Revision: 742115
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

* Mon Jul 07 2014 pterjan <pterjan> 1:3.1.3-5.mga5
+ Revision: 650326
- Sync with fedora (fixes build)

* Tue Oct 22 2013 dmorgan <dmorgan> 1:3.1.3-4.mga4
+ Revision: 546278
- Build with xmvn
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild

* Thu Oct 10 2013 luigiwalser <luigiwalser> 1:3.1.3-2.mga4
+ Revision: 494406
- BR maven-local for mvn-rpmbuild

* Thu Jan 17 2013 dmorgan <dmorgan> 1:3.1.3-1.mga3
+ Revision: 389214
- New version 3.1.3
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Apr 27 2011 dmorgan <dmorgan> 0:2.0.1-10.mga1
+ Revision: 92197
- Sync with fedora spec file
  Remove gcj support

* Fri Jan 21 2011 ennael <ennael> 0:2.0.1-8.mga1
+ Revision: 30420
- imported package xmlrpc

